/*
         Endeavour Add/Extract Objects From/To Archive Options Dialog
 */

#ifndef ARCHIVE_OPTIONS_DLG_H
#define ARCHIVE_OPTIONS_DLG_H

#include <gtk/gtk.h>
#include "edv_types.h"


extern gboolean EDVArchAddOptsGetResponse(
	edv_core_struct *core,
	GtkWidget *ref_toplevel,
	const gchar *arch_path,
	gchar **password,
	gboolean *recursive,
	gint *compression,		/* 0 to 100 */
	gboolean *dereference_links
);
extern gboolean EDVArchExtractOptsGetResponse(
	edv_core_struct *core,
	GtkWidget *ref_toplevel,
	const gchar *arch_path,
	gchar **password,
	gboolean *preserve_directories,
	gboolean *preserve_timestamps
);


#endif	/* ARCHIVE_OPTIONS_DLG_H */
